@@ -201,6 +201,9 @@ class Renderer(base.Renderer):
     def _query(self):
         keywords = []        
         context = aq_inner(self.context)
+
+        contents = [self.context]
+
         
         # TODO: test if a collection limited to 3 items show anything...
         # get items in folder or collection
@@ -208,10 +211,13 @@ class Renderer(base.Renderer):
         if self.context.isPrincipiaFolderish:
             folder_contents = self._contents()
             folder_contents = map(lambda x: x.getObject(), folder_contents)     
+        else:
+            print 'not a folder'
+            # Add references and back-references (related items)
+            if callable(getattr(context, 'getReferences')) and callable(getattr(context, 'getBackReferences')):
+                contents = context.getReferences() + context.getBackReferences()
 
-        contents = [self.context]
-        # Add references and back-references (related items)
-        contents = context.getReferences() + context.getBackReferences()
+        
         contents += folder_contents
         
         search_query = self._itemsQuery(contents)
@@ -231,15 +237,10 @@ class Renderer(base.Renderer):
 
         exclude_items = map(lambda x: x.getPath(), content)
         exclude_items += [here_path]  
-        
-                
-
-        
 
         search_query = self._query()
         #print 'search_query = '+search_query
-        
-        
+
         catalog = plone_tools.catalog()
         limit = self.data.count
         # increase by one since we'll get the current item
